package controller

import (
	"context"
	"fmt"
	"micro-bundle/internal/logic"
	"micro-bundle/pb/bundle"
	"micro-bundle/pkg/utils"
)

type BundleProvider struct {
	bundle.UnimplementedBundleServer
}

// 套餐相关
func (b *BundleProvider) CreateBundle(_ context.Context, req *bundle.BundleProfile) (res *bundle.CommonResponse, err error) {
	return logic.CreateBundle(req)
}

func (b *BundleProvider) UpdateBundle(_ context.Context, req *bundle.BundleProfile) (res *bundle.CommonResponse, err error) {
	return logic.UpdateBundle(req)
}

func (b *BundleProvider) DeleteBundle(_ context.Context, req *bundle.DelBundleRequest) (res *bundle.CommonResponse, err error) {
	return logic.DeleteBundle(req)
}

func (b *BundleProvider) BundleList(_ context.Context, req *bundle.BundleListRequest) (res *bundle.BundleListResponse, err error) {
	return logic.BundleList(req)
}

func (b *BundleProvider) BundleDetail(_ context.Context, req *bundle.BundleDetailRequest) (res *bundle.BundleDetailResponse, err error) {
	return logic.BundleDetail(req)
}

// 订单相关
func (b *BundleProvider) CreateOrderRecord(_ context.Context, req *bundle.OrderCreateRecord) (res *bundle.CommonResponse, err error) {
	return logic.CreateOrderRecord(req)
}

func (b *BundleProvider) UpdateOrderRecord(_ context.Context, req *bundle.OrderRecord) (res *bundle.CommonResponse, err error) {
	return logic.UpdateOrderRecord(req)
}

func (b *BundleProvider) UpdateOrderRecordByOrderNo(_ context.Context, req *bundle.OrderRecord) (res *bundle.CommonResponse, err error) {
	return logic.UpdateOrderRecordByOrderNo(req)
}

func (b *BundleProvider) OrderRecordsList(_ context.Context, req *bundle.OrderRecordsRequest) (res *bundle.OrderRecordsResponse, err error) {
	return logic.OrderRecordsList(req)
}

func (b *BundleProvider) OrderRecordsDetail(_ context.Context, req *bundle.OrderRecordsDetailRequest) (res *bundle.OrderRecordsDetailResponse, err error) {
	return logic.OrderRecordsDetail(req)
}

// 增值套餐相关
func (b *BundleProvider) CreateValueAddBundle(_ context.Context, req *bundle.CreateValueAddBundleRequest) (res *bundle.CreateValueAddBundleResponse, err error) {
	if err = req.Validate(); err != nil {
		err = utils.SubstrError(err)
		fmt.Println(err)
		return nil, err
	}

	return logic.CreateValueAddBundle(req)
}

func (b *BundleProvider) ValueAddBundleList(_ context.Context, req *bundle.ValueAddBundleListRequest) (res *bundle.ValueAddBundleListResponse, err error) {
	return logic.ValueAddBundleList(req)
}

func (b *BundleProvider) ValueAddBundleDetail(_ context.Context, req *bundle.ValueAddBundleDetailRequest) (res *bundle.ValueAddBundleDetailResponse, err error) {
	return logic.ValueAddBundleDetail(req)
}

// 财务确认
func (b *BundleProvider) UpdateFinancialConfirmationStatus(_ context.Context, req *bundle.FinancialConfirmationRequest) (res *bundle.CommonResponse, err error) {
	return logic.UpdateFinancialConfirmationStatus(req)
}
func (b *BundleProvider) PackagePriceAndTime(_ context.Context, req *bundle.OrderRecord) (res *bundle.PackagePriceAndTimeResponse, err error) {
	return logic.PackagePriceAndTime(req)
}

// 创建增值服务订单
func (b *BundleProvider) CreateOrderAddRecord(_ context.Context, req *bundle.OrderAddRecord) (res *bundle.CommonResponse, err error) {
	return logic.CreateOrderAddRecord(req)
}
func (b *BundleProvider) OrderRecordsListV2(_ context.Context, req *bundle.OrderRecordsRequestV2) (res *bundle.OrderRecordsResponseV2, err error) {
	return logic.OrderRecordsListV2(req)
}
func (b *BundleProvider) OrderListByOrderNo(_ context.Context, req *bundle.OrderInfoByOrderNoRequest) (res *bundle.OrderInfoByOrderNoResp, err error) {
	return logic.OrderListByOrderNo(req)
}

// 对账单
func (b *BundleProvider) GetReconciliationList(_ context.Context, req *bundle.GetReconciliationListReq) (res *bundle.GetReconciliationListResp, err error) {
	return logic.GetReconciliationList(req)
}

func (b *BundleProvider) CreateReconciliation(_ context.Context, req *bundle.ReconciliationInfo) (res *bundle.CommonResponse, err error) {
	return logic.CreateReconciliation(req)
}

func (b *BundleProvider) UpdateReconciliation(_ context.Context, req *bundle.ReconciliationInfo) (res *bundle.CommonResponse, err error) {
	return logic.UpdateReconciliation(req)
}

func (b *BundleProvider) OnlyAddValueListByOrderNo(_ context.Context, req *bundle.OnlyAddValueListByOrderNoRequest) (res *bundle.OnlyAddValueListByOrderNoResp, err error) {
	return logic.OnlyAddValueListByOrderNo(req)
}

func (b *BundleProvider) UpdateReconciliationStatusBySerialNumber(_ context.Context, req *bundle.UpdateStatusAndPayTimeBySerialNumber) (res *bundle.CommonResponse, err error) {
	return logic.UpdateReconciliationStatusBySerialNumber(req)
}
