package model

import (
	"gorm.io/plugin/soft_delete"
)

type CostLog struct {
	Uuid          string `gorm:"column:uuid;type:varchar(50);NOT NULL;primary_key;" json:"id"`
	ArtistUuid    string `gorm:"column:artist_uuid;type:varchar(50);NOT NULL;index:idx_artist_uuid;default:'';comment:艺人ID" json:"artistUuid"`
	ArtistName    string `gorm:"column:artist_name;type:varchar(50);NOT NULL;default:'';comment:艺人名称" json:"artistName"`
	ArtistPhone   string `gorm:"column:artist_phone;type:varchar(50);NOT NULL;default:'';comment:艺人手机号" json:"artistPhone"`
	WorkUuid      string `gorm:"column:work_uuid;type:varchar(50);NOT NULL;index:idx_work_uuid;default:'';comment:作品uuid" json:"workUuid"`
	WorkCategory  uint8  `gorm:"column:work_category;type:tinyint(1);NOT NULL;default:1;comment: 1 图文 2 视频" json:"workCategory"`
	BundleUuid    string `gorm:"column:bundle_uuid;type:varchar(50);NOT NULL;index:idx_bundle_uuid;default:'';comment:套餐ID uuid" json:"bundleUuid"`
	BundleName    string `gorm:"column:bundle_name;type:varchar(50);NOT NULL;default:'';comment:套餐名称" json:"bundleName"`
	PlatformIDs   string `gorm:"column:platform_ids;type:json;NOT NULL;comment:发布平台ID集合" json:"platformIDs"`
	MediaNames    string `gorm:"column:media_names;type:varchar(600);NOT NULL;default:'';comment:自媒体账号名称集合" json:"mediaNames"`
	MediaAccIDs   string `gorm:"column:media_acc_ids;type:varchar(600);NOT NULL;default:'';comment:自媒体账号ID集合" json:"mediaAccIDs"`
	WorkTitle     string `gorm:"column:work_title;type:varchar(50);NOT NULL;" json:"workTitle"`
	SubmitTime    string `gorm:"column:submit_time;type:varchar(50);NOT NULL;default:'';comment:提交时间" json:"submitTime"`
	OperatorName  string `gorm:"column:operator_name;type:varchar(50);NOT NULL;default:'';comment:操作人名称" json:"operatorName"`
	OperatorID    string `gorm:"column:operator_id;type:varchar(50);NOT NULL;default:'';comment:操作人ID" json:"operatorID"`
	OperatorPhone string `gorm:"column:operator_phone;type:varchar(50);NOT NULL;default:'';comment:操作人手机号" json:"operatorPhone"`
	Status        uint8  `gorm:"column:status;type:tinyint(1);NOT NULL;default:1;comment: 1 有效 2 失效" json:"status"`
	CreatedAt     int    `gorm:"column:created_at;type:int(11);autoCreateTime" json:"createdAt"`
	UpdatedAt     int    `gorm:"column:updated_at;type:int(11);autoCreateTime" json:"updatedAt"`
	DeletedAt     soft_delete.DeletedAt
}

func (CostLog) TableName() string {
	return "cast_cost_log"
}

type CastWorkImage struct {
	Uuid      string `json:"uuid" gorm:"uuid"`
	WorkUuid  string `json:"work_uuid" gorm:"work_uuid"`   // 作品uuid
	ImageUrls string `json:"image_urls" gorm:"image_urls"` // 图片url集合
	CreatedAt int64  `json:"created_at" gorm:"created_at"`
	UpdatedAt int64  `json:"updated_at" gorm:"updated_at"`
	DeletedAt int64  `json:"deleted_at" gorm:"deleted_at"`
}

// TableName 表名称
func (*CastWorkImage) TableName() string {
	return "cast_work_image"
}

type CastWorkVideo struct {
	Uuid      string `json:"uuid" gorm:"uuid"`
	WorkUuid  string `json:"work_uuid" gorm:"work_uuid"` // 作品uuid
	CoverUrl  string `json:"cover_url" gorm:"cover_url"` // 封面url
	VideoUrl  string `json:"video_url" gorm:"video_url"` // 视频url
	CreatedAt int64  `json:"created_at" gorm:"created_at"`
	UpdatedAt int64  `json:"updated_at" gorm:"updated_at"`
	DeletedAt int64  `json:"deleted_at" gorm:"deleted_at"`
}

// TableName 表名称
func (*CastWorkVideo) TableName() string {
	return "cast_work_video"
}

// CastWork undefined
type CastWork struct {
	Uuid             string `json:"uuid" gorm:"uuid"`
	ArtistUuid       string `json:"artist_uuid" gorm:"artist_uuid"`               // 艺人ID
	MediaAccUserIds  string `json:"media_acc_user_ids" gorm:"media_acc_user_ids"` // 自媒体账号user_ids集合
	MediaNames       string `json:"media_names" gorm:"media_names"`               // 自媒体账号名称集合
	ArtistName       string `json:"artist_name" gorm:"artist_name"`               // 艺人名称
	ArtistPhone      string `json:"artist_phone" gorm:"artist_phone"`             // 艺人手机号
	WorkCategory     int8   `json:"work_category" gorm:"work_category"`           //  1 图文 2 视频
	SubmitTime       string `json:"submit_time" gorm:"submit_time"`               // 提交时间
	StatusUpdateTime string `json:"status_update_time" gorm:"status_update_time"` // 状态更新时间
	Status           int8   `json:"status" gorm:"status"`                         //  1 待提交 2 审核中 3 审核失败 4 待艺人确认 5 艺人驳回 6 发布成功 7 发布失败
	Title            string `json:"title" gorm:"title"`
	Content          string `json:"content" gorm:"content"`
	PublishConfig    string `json:"publish_config" gorm:"publish_config"` // 发布配置
	CreatedAt        int64  `json:"created_at" gorm:"created_at"`
	UpdatedAt        int64  `json:"updated_at" gorm:"updated_at"`
	DeletedAt        int64  `json:"deleted_at" gorm:"deleted_at"`
	Cost             int8   `json:"cost" gorm:"cost"`                     //  1 消耗 2 未消耗
	ConfirmRemark    string `json:"confirm_remark" gorm:"confirm_remark"` // 艺人确认备注
	ApprovalId       string `json:"approval_id" gorm:"approval_id"`       // 审批ID
}

// TableName 表名称
func (*CastWork) TableName() string {
	return "cast_work"
}

type CastWorkLog struct {
	Uuid            string `gorm:"column:uuid;type:varchar(50);primary_key" json:"uuid"`
	WorkUuid        string `gorm:"column:work_uuid;type:varchar(50);comment:作品uuid;NOT NULL" json:"work_uuid"`
	Title           string `gorm:"column:title;type:varchar(50);NOT NULL" json:"title"`
	Content         string `gorm:"column:content;type:varchar(2000);NOT NULL" json:"content"`
	WorkCategory    int    `gorm:"column:work_category;type:tinyint(1);default:1;comment: 1 图文 2 视频;NOT NULL" json:"work_category"`
	UpdateTime      string `gorm:"column:update_time;type:varchar(50);comment:更新时间;NOT NULL" json:"update_time"`
	WorkStatus      int    `gorm:"column:work_status;type:tinyint(1);default:1;comment: 1 待提交 2 审核中 3 审核失败 4 待艺人确认 5 艺人驳回 6 发布成功 7 发布失败;NOT NULL" json:"work_status"`
	PlatformIds     string `gorm:"column:platform_ids;type:json;comment:发布平台ID集合 TIKTOK= 1, YOUTUBE = 2, INS = 3;NOT NULL" json:"platform_ids"`
	ArtistName      string `gorm:"column:artist_name;type:varchar(50);comment:艺人名称;NOT NULL" json:"artist_name"`
	ArtistUuid      string `gorm:"column:artist_uuid;type:varchar(50);comment:艺人ID;NOT NULL" json:"artist_uuid"`
	MediaAccUserIds string `gorm:"column:media_acc_user_ids;type:json;comment:自媒体账号user_ids集合;NOT NULL" json:"media_acc_user_ids"`
	MediaNames      string `gorm:"column:media_names;type:varchar(600);comment:自媒体账号名称集合;NOT NULL" json:"media_names"`
	ConfirmedAt     int64  `gorm:"column:confirmed_at;type:int(11)" json:"confirmedAt"`
	CreatedAt       int    `gorm:"column:created_at;type:int(11)" json:"created_at"`
	UpdatedAt       int    `gorm:"column:updated_at;type:int(11)" json:"updated_at"`
	DeletedAt       uint64 `gorm:"column:deleted_at;type:bigint(20) unsigned" json:"deleted_at"`
}

func (m *CastWorkLog) TableName() string {
	return "cast_work_log"
}
